<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <source>Jump to today</source>
        <translation>Vai a oggi</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="29"/>
        <source>Jump to</source>
        <translation>Vai a</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="30"/>
        <source>New event</source>
        <translation>Nuovo evento</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="20"/>
        <source>Agenda</source>
        <translation>Cose da fare</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="38"/>
        <source>In advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="48"/>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="66"/>
        <source>Hours</source>
        <translation>Ore</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="86"/>
        <source>Minutes</source>
        <translation>Minuti</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="106"/>
        <source>Seconds</source>
        <translation>Secondi</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="20"/>
        <source>Enable</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="15"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="152"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="164"/>
        <source>Exact</source>
        <translation>Esatto</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="166"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>%n ora prima di</numerusform>
            <numerusform>%n ore prima di</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="167"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>%n minuto prima di</numerusform>
            <numerusform>%n minuti prima di</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="168"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>%n secondo prima di</numerusform>
            <numerusform>%n secondi prima di</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="170"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 prima di</translation>
    </message>
</context>
<context>
    <name>BirthdayEditDialog</name>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="6"/>
        <source>Edit event</source>
        <translation>Modifica evento</translation>
    </message>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="12"/>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>From beginning</source>
        <translation>Dall&apos;inizio</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="38"/>
        <source>From end</source>
        <translation>Dalla fine</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="49"/>
        <source>By day of month</source>
        <translation>Per giorno del mese</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="51"/>
        <source>By week of year</source>
        <translation>Per settimana dell&apos;anno</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="53"/>
        <source>By day of year</source>
        <translation>Per giorno dell&apos;anno</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="20"/>
        <source>By month</source>
        <translation>Per mese</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="21"/>
        <source>By day of week</source>
        <translation>Per giorno della settimana</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="55"/>
        <source>From beginning</source>
        <translation>Dall&apos;inizio</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="56"/>
        <source>From end</source>
        <translation>Dalla fine</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="52"/>
        <source>Edit calendar</source>
        <translation>Modifica calendario</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="27"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="37"/>
        <source>Birthday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="53"/>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="63"/>
        <source>Visible</source>
        <translation>Visibile</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="42"/>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="43"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="90"/>
        <source>New calendar</source>
        <translation>Nuovo calendario</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="94"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="141"/>
        <location filename="../settings/CalendarEditDialog.cpp" line="166"/>
        <source>Error occurred</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="175"/>
        <source>Save file</source>
        <translation>Salva file</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="193"/>
        <source>This calendar cannot be deleted. Delete all calendar content instead?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="201"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Eliminare questo calendario e tutti i suoi eventi, attività e note?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Modifica calendari</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="27"/>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n visibile</numerusform>
            <numerusform>%n visibile</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ChangeManager</name>
    <message>
        <location filename="../ChangeManager.cpp" line="239"/>
        <source>Delete event?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="242"/>
        <source>Delete task?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="245"/>
        <source>Delete note?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="248"/>
        <source>Delete component?</source>
        <translation>Eliminare elemento?</translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Tutto il⏎
giorno</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="71"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="183"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="184"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="185"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>DateFormatDialog</name>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="6"/>
        <source>Date formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="20"/>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="37"/>
        <source>Partial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="72"/>
        <source>Day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="89"/>
        <source>Month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="106"/>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.cpp" line="24"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="27"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="181"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Settimana %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.ui" line="6"/>
        <source>Select date</source>
        <translation>Seleziona data</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Inserisci il numero del giorno</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Giorno precedente</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Giorno successivo</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Vai a oggi</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Vai a</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n evento</numerusform>
            <numerusform>%n eventi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n attività</numerusform>
            <numerusform>%n attività</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n nota</numerusform>
            <numerusform>%n note</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Dove</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Tutto il giorno</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Da</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Time zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="125"/>
        <source>Repeat</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="142"/>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="149"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="30"/>
        <source>Edit event</source>
        <translation>Modifica evento</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="33"/>
        <source>New event</source>
        <translation>Nuovo evento</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Evento</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="182"/>
        <source>Previous event</source>
        <translation>Evento precedente</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="187"/>
        <source>Next event</source>
        <translation>Evento successivo</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="192"/>
        <source>Edit event</source>
        <translation>Modifica Evento</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="197"/>
        <source>Delete event</source>
        <translation>Elimina evento</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="202"/>
        <source>Clone event</source>
        <translation>Clona evento</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="207"/>
        <source>Automatic links</source>
        <translation>Link automatici</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="146"/>
        <source>From</source>
        <translation>Da</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="146"/>
        <source>On</source>
        <translation>Il</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="216"/>
        <location filename="../EventWindow.cpp" line="237"/>
        <source>No more events</source>
        <translation>Non ci sono altri eventi</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="268"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="269"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="270"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../ImportDialog.ui" line="6"/>
        <source>Select calendar</source>
        <translation>Seleziona calendario</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="44"/>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="50"/>
        <source>New calendar</source>
        <translation>Nuovo calendario</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="77"/>
        <source>Importing aborted</source>
        <translation>Importazione interrotta</translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="112"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n evento</numerusform>
            <numerusform>%n eventi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="113"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n attività</numerusform>
            <numerusform>%n attività</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="114"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n nota</numerusform>
            <numerusform>%n note</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="126"/>
        <location filename="../ImportDialog.cpp" line="194"/>
        <source>Error occurred</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="187"/>
        <source>Some items already in calendar</source>
        <translation>Alcuni oggetti sono già nel calendario</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="22"/>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="21"/>
        <source>Edit note</source>
        <translation>Modifica nota</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>New note</source>
        <translation>Nuova nota</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="28"/>
        <source>New note</source>
        <translation>Nuova nota</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="47"/>
        <source>Notes</source>
        <translation>Note</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="124"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="125"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="126"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="63"/>
        <source>Month</source>
        <translation>Mese</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="64"/>
        <source>Week</source>
        <translation>Settimana</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="65"/>
        <source>Agenda</source>
        <translation>Cose da fare</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="66"/>
        <source>Tasks</source>
        <translation>Attività</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="67"/>
        <source>Notes</source>
        <translation>Note</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="68"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="60"/>
        <source>Previous month</source>
        <translation>Mese precedente</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="61"/>
        <source>Next month</source>
        <translation>Mese successivo</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="62"/>
        <source>Jump to today</source>
        <translation>Vai a oggi</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Jump to</source>
        <translation>Vai a</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>New event</source>
        <translation>Nuovo evento</translation>
    </message>
</context>
<context>
    <name>NewComponentWidget</name>
    <message>
        <location filename="../NewComponentWidget.h" line="24"/>
        <source>New event</source>
        <translation>Nuovo evento</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../CWrapper.h" line="59"/>
        <source>Private</source>
        <translation>Privato</translation>
    </message>
    <message>
        <location filename="../CWrapper.h" line="61"/>
        <source>Birthdays</source>
        <translation>Compleanni</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Ricorrenza</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="24"/>
        <source>Repeat</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="34"/>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="55"/>
        <source>Frequency</source>
        <translation>Frequenza</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
        <source>Daily</source>
        <translation>Giornaliero</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
        <source>Weekly</source>
        <translation>Settimanale</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
        <source>Monthly</source>
        <translation>Mensile</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
        <source>Yearly</source>
        <translation>Annuale</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="89"/>
        <source>Interval</source>
        <translation>Intervallo</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
        <source>Forever</source>
        <translation>Per sempre</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
        <source>Until</source>
        <translation>Fino a</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="123"/>
        <source>Count</source>
        <translation>Numero di volte</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="188"/>
        <source>Week start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="36"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="37"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="39"/>
        <source>External</source>
        <translation>Esterno</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="41"/>
        <source>Every day</source>
        <translation>Ogni giorno</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="43"/>
        <source>Every workday</source>
        <translation>Ogni giorno lavorativo</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="45"/>
        <source>Every week</source>
        <translation>Ogni settimana</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="47"/>
        <source>Every month</source>
        <translation>Ogni mese</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="49"/>
        <source>Every year</source>
        <translation>Ogni anno</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="51"/>
        <source>Complex</source>
        <translation>Composto</translation>
    </message>
</context>
<context>
    <name>RulePickDialog</name>
    <message>
        <location filename="../recurrence/RulePickDialog.ui" line="6"/>
        <source>Select rule</source>
        <translation>Seleziona metodo</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="16"/>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="17"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
</context>
<context>
    <name>RulePickSelector</name>
    <message>
        <location filename="../recurrence/RulePickSelector.cpp" line="14"/>
        <source>Rule %1 of %2</source>
        <translation>Metodo %1 di %2</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="31"/>
        <source>Edit calendars</source>
        <translation>Modifica calendari</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="41"/>
        <source>Alarm tone</source>
        <translation>Tono allarme</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="51"/>
        <source>Delete events</source>
        <translation>Elimina eventi</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="61"/>
        <source>Delete tasks</source>
        <translation>Elimina attività</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="71"/>
        <source>First day of week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="81"/>
        <source>Editable time zones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="88"/>
        <source>Date formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="19"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="66"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="68"/>
        <location filename="../settings/SettingsDialog.cpp" line="70"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Più vecchi di %n settimana</numerusform>
            <numerusform>Più vecchi di %n settimane</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="72"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Più vecchi di %n mese</numerusform>
            <numerusform>Più vecchi di %n mesi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="74"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Più vecchi di %n anno</numerusform>
            <numerusform>Più vecchi di %n anni</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Time zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <source>Calendar</source>
        <translation>Calendario</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="56"/>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="63"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="28"/>
        <source>Edit task</source>
        <translation>Modifica attività</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="31"/>
        <source>New task</source>
        <translation>Nuova attività</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Attività</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Scadenza</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="169"/>
        <source>Edit task</source>
        <translation>Modifica attività</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="174"/>
        <source>Delete task</source>
        <translation>Elimina attività</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="179"/>
        <source>Clone task</source>
        <translation>Clona attività</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="184"/>
        <source>Automatic links</source>
        <translation>Link automatici</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="171"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="172"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="173"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="34"/>
        <location filename="../TodosPlug.cpp" line="329"/>
        <source>New task</source>
        <translation>Nuova attività</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Hide completed</source>
        <translation>Nascondi completati</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="42"/>
        <source>Group by calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="43"/>
        <source>Delete completed</source>
        <translation>Elimina completati</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="71"/>
        <source>Tasks</source>
        <translation>Attività</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="332"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="333"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="334"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="379"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Elimina attività completate da tutti i calendari?</translation>
    </message>
</context>
<context>
    <name>TunePickDialog</name>
    <message>
        <location filename="../settings/TunePickDialog.ui" line="6"/>
        <source>Choose alarm tone</source>
        <translation>Scegli tono allarme</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="17"/>
        <source>More</source>
        <translation>Altro</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="67"/>
        <source>Add alarm tone</source>
        <translation>Aggiungi tono allarme</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="33"/>
        <source>w%1</source>
        <translation>w%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Previous week</source>
        <translation>Settimana precedente</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Next week</source>
        <translation>Settimana successiva</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to today</source>
        <translation>Vai a oggi</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>Jump to</source>
        <translation>Vai a</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="47"/>
        <source>New event</source>
        <translation>Nuovo evento</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="70"/>
        <source>Week %1 (%2)</source>
        <translation>Settimana %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="364"/>
        <source>All day</source>
        <translation>Tutto il giorno</translation>
    </message>
</context>
<context>
    <name>ZonePickDialog</name>
    <message>
        <location filename="../ZonePickDialog.ui" line="6"/>
        <source>Time zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.ui" line="39"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.cpp" line="79"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
